@@ -67,15 +67,6 @@ for l in absoluteurls:
     except:
         buggyurls.append(l)
         print("Error")
-nbuggyurls = len(buggyurls)
-if (nbuggyurls == 1):
-    print("%s url with troubles:" % str(nbuggyurls))
-else:
-    print("%s url with troubles:" % str(nbuggyurls))    
 
+print("Urls with troubles:")
 print(buggyurls)
-nurls = len(links) - len(buggyurls) 
-if (nurls == 1):
-    print(str(nurls) + " good url")
-else:
-    print(str(nurls) + " good urls")    
