@@ -23,8 +23,16 @@
 
 from unittest import TestCase
 from xml.dom import minidom
+import xml.parsers.expat
 import xml.etree.ElementTree as ET
 
+def start_element(name, attrs):
+    print('Start element:', name, attrs)
+def end_element(name):
+    print('End element:', name)
+def char_data(data):
+    print('Character data:', repr(data))
+
 class TestXml(TestCase):
 
     def test_minidom(self):
